@@ -5,21 +5,42 @@ import numpy as np
 
 
 class JayaClasic(JayaBase):
+    """Jaya clasic class
 
-    def run(self, number_iterations):
+    Args:
+        numSolutions (int): Number of solutions of population.
+        listVars (list): Range list.
+        functionToEvaluate (funtion): Function to minimize or maximize.
+        listConstraints (list, optional): Constraint list. Defaults to [].
+        population (Population, optional): Population. Defaults to None.
+    """
+
+    def run(self, number_iterations, rn=[]):
+        """Run method
+
+        Args:
+            number_iterations (int): Number of iterations.
+
+        Returns:
+            Population: Final population.
+        """
+        if len(rn) == 0:
+            self.rn = self.generate_rn(number_iterations)
+        else:
+            assert number_iterations == len(rn)
+            assert len(rn[0]) == self.cantVars
+            assert len(rn[0][0]) == 2
+            self.rn = rn
         for i in range(number_iterations):
             result = self.population.getBestAndWorst()
-            np.random.seed()
-            r1 = np.random.rand(self.cantVars)
-            r2 = np.random.rand(self.cantVars)
             for solution in self.population.solutions:
                 solt = []
                 for v_item, v_value in enumerate(solution.solution):
                     solt.append(self.listVars[v_item].convert(
                         (
-                            v_value + r1[v_item] *
+                            v_value + self.rn[i][v_item][0] *
                             (result['best_solution'][v_item] - abs(v_value))
-                            - r2[v_item] *
+                            - self.rn[i][v_item][1] *
                             (result['worst_solution'][v_item]-abs(v_value)))
                     ))
                 auxSolution = Solution(
