@@ -1,15 +1,33 @@
 # -*- coding: utf-8 -*-
+import numpy as np
+
 from .base import JayaBase
 from .clasic import JayaClasic
 from pyJaya.population import Population
 from pyJaya.solution import Solution
-import numpy as np
 
 
 class JayaQuasiOppositional(JayaBase):
+    """Jaya clasic class
+
+    Args:
+        numSolutions (int): Number of solutions of population.
+        listVars (list): Range list.
+        functionToEvaluate (funtion): Function to minimize or maximize.
+        listConstraints (list, optional): Constraint list. Defaults to [].
+        population (Population, optional): Population. Defaults to None.
+    """
 
     def generateQuasiOpposite(self, population):
-        newPopulation = Population(self.minimax)
+        """Generate quasi-opposite population
+
+        Args:
+            population (Population): Population to generate quasi-opposite.
+
+        Returns:
+            Population: [description]
+        """
+        newPopulation = Population(self.minimax, solutions=[])
         for solution in population.solutions:
             newSolution = Solution(
                 self.listVars, self.functionToEvaluate, self.listConstraints)
@@ -27,13 +45,18 @@ class JayaQuasiOppositional(JayaBase):
         return newPopulation
 
     def newPopulation(self):
-        auxPopulation = Population(self.minimax)
+        """New population with quasi-opposite elements.
+
+        Returns:
+            Population: Population with quasi-opposite elements.
+        """
+        auxPopulation = Population(self.minimax, solutions=[])
         quasiOppositePopulation = self.generateQuasiOpposite(self.population)
         for s in self.population.solutions:
             auxPopulation.solutions.append(s)
         for s in quasiOppositePopulation.solutions:
             auxPopulation.solutions.append(s)
-        newPopulation = Population(self.minimax)
+        newPopulation = Population(self.minimax, solutions=[])
         if self.minimax:
             for s in auxPopulation.sorted()[-self.numSolutions:]:
                 newPopulation.solutions.append(s)
@@ -42,12 +65,27 @@ class JayaQuasiOppositional(JayaBase):
                 newPopulation.solutions.append(s)
         return newPopulation
 
-    def run(self, numIterations):
-        for i in range(numIterations):
+    def run(self, number_iterations, rn=[]):
+        """Run method
+
+        Args:
+            number_iterations (int): Number of iterations.
+
+        Returns:
+            Population: Final population.
+        """
+        if len(rn) == 0:
+            self.rn = self.generate_rn(number_iterations)
+        else:
+            assert number_iterations == len(rn)
+            assert len(rn[0]) == self.cantVars
+            assert len(rn[0][0]) == 2
+            self.rn = rn
+        for i in range(number_iterations):
             self.population = self.newPopulation()
             self.population = JayaClasic(
                 self.population.size(), self.listVars,
-                self.functionToEvaluate, self.listConstraints,
-                self.population).run(1)
+                self.functionToEvaluate, listConstraints=self.listConstraints,
+                population=self.population).run(1, [self.rn[i]])
 
         return self.population
