@@ -6,8 +6,25 @@ import numpy as np
 
 
 class JayaSAMP(JayaBase):
+    """Jaya SAMP class
+
+    Args:
+        numSolutions (int): Number of solutions of population.
+        listVars (list): Range list.
+        functionToEvaluate (funtion): Function to minimize or maximize.
+        listConstraints (list, optional): Constraint list. Defaults to [].
+        population (Population, optional): Population. Defaults to None.
+    """
 
     def sprint(self, population):
+        """Jaya clasic to sub-population
+
+        Args:
+            population (Population): Population to evaluate whit Jaya clasic.
+
+        Returns:
+            Population: Sprint final population.
+        """
         result = population.getBestAndWorst()
         r1 = np.random.rand(self.cantVars)
         r2 = np.random.rand(self.cantVars)
@@ -35,7 +52,22 @@ class JayaSAMP(JayaBase):
                     solution.setSolution(auxSolution.solution)
         return population
 
-    def run(self, number_iterations):
+    def run(self, number_iterations, rn=[]):
+        """Run method
+
+        Args:
+            number_iterations (int): Number of iterations.
+
+        Returns:
+            Population: Final population.
+        """
+        if len(rn) == 0:
+            self.rn = self.generate_rn(number_iterations)
+        else:
+            assert number_iterations == len(rn)
+            assert len(rn[0]) == self.cantVars
+            assert len(rn[0][0]) == 2
+            self.rn = rn
         result = self.population.getBestAndWorst()
         bestValue = result['best_value']
         for i in range(number_iterations):
@@ -44,7 +76,7 @@ class JayaSAMP(JayaBase):
                 subPopulations = self.population.divideInTo(m)
                 for p in subPopulations:
                     p = self.sprint(p)
-                newPopulation = Population(self.minimax)
+                newPopulation = Population(self.minimax, solutions=[])
                 newPopulation.merge(subPopulations)
                 if self.minimax:
                     nBest = newPopulation.getBestAndWorst()['best_value']
@@ -68,7 +100,7 @@ class JayaSAMP(JayaBase):
                     subPopulations = self.population.divideInTo(m)
                     for p in subPopulations:
                         p = self.sprint(p)
-                    newPopulation = Population(self.minimax)
+                    newPopulation = Population(self.minimax, solutions=[])
                     newPopulation.merge(subPopulations)
                     nBest = newPopulation.getBestAndWorst()['best_value']
                     lBest = self.population.getBestAndWorst()['best_value']
@@ -85,10 +117,10 @@ class JayaSAMP(JayaBase):
                     subPopulations = self.population.divideInTo(m)
                     for p in subPopulations:
                         p = self.sprint(p)
-                    newPopulation = Population(self.minimax)
+                    newPopulation = Population(self.minimax, solutions=[])
                     newPopulation.merge(subPopulations)
                     newBest = newPopulation.getBestAndWorst()['best_value']
                     lastBest = self.population.getBestAndWorst()['best_value']
                     if newBest < lastBest:
                         self.population = newPopulation
-        return self.population.getBestAndWorst()
+        return self.population
